@@ -7,7 +7,7 @@
  * @date   2006-09-15
  * @brief  Exif manipulation methods
  *
- * @author Copyright (C) 2006-2013 by Gilles Caulier
+ * @author Copyright (C) 2006-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -54,9 +54,13 @@ bool KExiv2::canWriteExif(const QString& filePath)
     catch( Exiv2::Error& e )
     {
         std::string s(e.what());
-        kDebug() << "Cannot check Exif access mode using Exiv2 (Error #"
+        kError() << "Cannot check Exif access mode using Exiv2 (Error #"
                  << e.code() << ": " << s.c_str() << ")";
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -77,6 +81,10 @@ bool KExiv2::clearExif() const
     {
         d->printExiv2ExceptionError("Cannot clear Exif data using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -113,6 +121,10 @@ QByteArray KExiv2::getExifEncoded(bool addExifHeader) const
 
         d->printExiv2ExceptionError("Cannot get Exif data using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QByteArray();
 }
@@ -130,10 +142,14 @@ bool KExiv2::setExif(const QByteArray& data) const
     catch( Exiv2::Error& e )
     {
         if (!d->filePath.isEmpty())
-            kDebug() << "From file " << d->filePath.toAscii().constData();
+            kError() << "From file " << d->filePath.toAscii().constData();
 
         d->printExiv2ExceptionError("Cannot set Exif data using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -179,15 +195,22 @@ KExiv2::MetaDataMap KExiv2::getExifTagsDataList(const QStringList& exifKeysFilte
 
             // We apply a filter to get only the Exif tags that we need.
 
-            if (!invertSelection)
+            if (!exifKeysFilter.isEmpty())
             {
-                if (exifKeysFilter.contains(key.section('.', 1, 1)))
-                    metaDataMap.insert(key, tagValue);
+                if (!invertSelection)
+                {
+                    if (exifKeysFilter.contains(key.section('.', 1, 1)))
+                        metaDataMap.insert(key, tagValue);
+                }
+                else
+                {
+                    if (!exifKeysFilter.contains(key.section('.', 1, 1)))
+                        metaDataMap.insert(key, tagValue);
+                }
             }
-            else
+            else // else no filter at all.
             {
-                if (!exifKeysFilter.contains(key.section('.', 1, 1)))
-                    metaDataMap.insert(key, tagValue);
+                metaDataMap.insert(key, tagValue);
             }
         }
 
@@ -197,6 +220,10 @@ KExiv2::MetaDataMap KExiv2::getExifTagsDataList(const QStringList& exifKeysFilte
     {
         d->printExiv2ExceptionError("Cannot parse EXIF metadata using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return MetaDataMap();
 }
@@ -245,6 +272,10 @@ QString KExiv2::getExifComment() const
     {
         d->printExiv2ExceptionError("Cannot find Exif User Comment using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QString();
 }
@@ -305,6 +336,10 @@ bool KExiv2::setExifComment(const QString& comment, bool setProgramName) const
     {
         d->printExiv2ExceptionError("Cannot set Exif Comment using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -322,6 +357,10 @@ QString KExiv2::getExifTagTitle(const char* exifTagName)
     {
         d->printExiv2ExceptionError("Cannot get metadata tag title using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QString();
 }
@@ -339,6 +378,10 @@ QString KExiv2::getExifTagDescription(const char* exifTagName)
     {
         d->printExiv2ExceptionError("Cannot get metadata tag description using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QString();
 }
@@ -363,6 +406,10 @@ bool KExiv2::removeExifTag(const char* exifTagName, bool setProgramName) const
     {
         d->printExiv2ExceptionError("Cannot remove Exif tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -388,6 +435,10 @@ bool KExiv2::getExifTagRational(const char* exifTagName, long int& num, long int
         d->printExiv2ExceptionError(QString("Cannot find Exif Rational value from key '%1' "
                                          "into image using Exiv2 ").arg(exifTagName), e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -406,6 +457,10 @@ bool KExiv2::setExifTagLong(const char* exifTagName, long val, bool setProgramNa
     {
         d->printExiv2ExceptionError("Cannot set Exif tag long value into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -424,6 +479,10 @@ bool KExiv2::setExifTagRational(const char* exifTagName, long int num, long int
     {
         d->printExiv2ExceptionError("Cannot set Exif tag rational value into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -446,6 +505,10 @@ bool KExiv2::setExifTagData(const char* exifTagName, const QByteArray& data, boo
     {
         d->printExiv2ExceptionError("Cannot set Exif tag data into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -507,6 +570,10 @@ bool KExiv2::setExifTagVariant(const char* exifTagName, const QVariant& val,
             {
                 d->printExiv2ExceptionError("Cannot set Date & Time in image using Exiv2 ", e);
             }
+            catch(...)
+            {
+                kError() << "Default exception from Exiv2";
+            }
 
             return false;
         }
@@ -600,6 +667,10 @@ QString KExiv2::createExifUserStringFromValue(const char* exifTagName, const QVa
     {
         d->printExiv2ExceptionError("Cannot set Iptc tag string into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QString();
 }
@@ -628,6 +699,10 @@ bool KExiv2::getExifTagLong(const char* exifTagName, long& val, int component) c
         d->printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
                                     .arg(exifTagName), e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -655,6 +730,10 @@ QByteArray KExiv2::getExifTagData(const char* exifTagName) const
         d->printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
                                  .arg(exifTagName), e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QByteArray();
 }
@@ -737,6 +816,10 @@ QVariant KExiv2::getExifTagVariant(const char* exifTagName, bool rationalAsListO
         d->printExiv2ExceptionError(QString("Cannot find Exif key '%1' in the image using Exiv2 ")
                                     .arg(exifTagName), e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QVariant();
 }
@@ -766,6 +849,10 @@ QString KExiv2::getExifTagString(const char* exifTagName, bool escapeCR) const
         d->printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
                                  .arg(exifTagName), e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QString();
 }
@@ -784,6 +871,10 @@ bool KExiv2::setExifTagString(const char* exifTagName, const QString& value, boo
     {
         d->printExiv2ExceptionError("Cannot set Exif tag string into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -828,6 +919,10 @@ QImage KExiv2::getExifThumbnail(bool fixOrientation) const
     {
         d->printExiv2ExceptionError("Cannot get Exif Thumbnail using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return thumbnail;
 }
@@ -869,6 +964,10 @@ bool KExiv2::setExifThumbnail(const QImage& thumbImage, bool setProgramName) con
     {
         d->printExiv2ExceptionError("Cannot set Exif Thumbnail using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -924,6 +1023,10 @@ bool KExiv2::setTiffThumbnail(const QImage& thumbImage, bool setProgramName) con
     {
         d->printExiv2ExceptionError("Cannot set TIFF Thumbnail using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -941,6 +1044,10 @@ bool KExiv2::removeExifThumbnail() const
     {
         d->printExiv2ExceptionError("Cannot remove Exif Thumbnail using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -989,6 +1096,10 @@ KExiv2::TagsMap KExiv2::getStdExifTagsList() const
     {
         d->printExiv2ExceptionError("Cannot get Exif Tags list using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return TagsMap();
 }
@@ -1038,6 +1149,10 @@ KExiv2::TagsMap KExiv2::getMakernoteTagsList() const
     {
         d->printExiv2ExceptionError("Cannot get Makernote Tags list using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return TagsMap();
 }
